==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Draw/Image/ts/Image_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+132"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wszystkie pliki obrazów (%1)
Wszystkie pliki (*.*)</translatorcomment>
        <translation type="unfinished">Pliki</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wszystkie pliki obrazów (%1)</translatorcomment>
        <translation type="unfinished">Wszystkie pliki obrazów (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation type="unfinished">Wszystkie pliki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Bitmap import</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation type="unfinished">Format:</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="unfinished">Położenie</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Szerokość:
&amp;Szerokość papieru:</translatorcomment>
        <translation type="unfinished">Szerokość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zachowaj proporcje</translatorcomment>
        <translation type="unfinished">Zachowaj proporcje</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation type="unfinished">Wysokość:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation type="unfinished">Kąt:</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wstaw bitmapę</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Draw/Image/ts/Image_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Image</name>
    <message>
        <location filename="../Image.js" line="+133"/>
        <source>Files</source>
        <translatorcomment>--exact match--
--file: assistant_pl.ts--
Wszystkie pliki obrazów (%1)
Wszystkie pliki (*.*)</translatorcomment>
        <translation>Pliki</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>All Image Files (%1)</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wszystkie pliki obrazów (%1)</translatorcomment>
        <translation>Wszystkie pliki obrazów (%1)</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>All Files</source>
        <translatorcomment>--google--
Wszystkie pliki (*.*)
Pliki Designer UI (*.%1);;Wszystkie pliki (*)
Pliki z wydanymi tłumaczeniami (*.qm)
Wszystkie pliki (*)</translatorcomment>
        <translation>Wszystkie pliki</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Import Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Importowanie bitmapy</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Format:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Format:
Format:</translatorcomment>
        <translation>Format:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../Image.ui" line="+17"/>
        <source>Width:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Szerokość:
&amp;Szerokość papieru:</translatorcomment>
        <translation>Szerokość:</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>Keep proportions</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Zachowaj proporcje</translatorcomment>
        <translation>Zachowanie proporcji</translation>
    </message>
    <message>
        <location line="+17"/>
        <source>Height:</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wysokość:
Wysokość tekstu:</translatorcomment>
        <translation>Wysokość:</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Angle:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Wprowadź kąt:
Wskaż położenie linii wymiarowej:</translatorcomment>
        <translation>Kąt:</translation>
    </message>
    <message>
        <location filename="../ImageInit.js" line="+2"/>
        <source>Insert Bitmap</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wstaw bitmapę</translation>
    </message>
</context>
</TS>
